pub enum Yes {
Ok,
Other(Other),
}Expand description
Used for deserializing values in some of itunes tags.
The only possible value in some of the tags is “Yes”, which this enum is meant to reflect.
Variants
Implementations